<?php

namespace Drupal\webform_datetime_24h\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Webform 24h settings for available languages.
 */
class WebformDatetime24hSettingsForm extends ConfigFormBase {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected LanguageManagerInterface $languageManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->languageManager = $container->get('language_manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['webform_datetime_24h.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_datetime_24h_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('webform_datetime_24h.settings');
    $languages = $this->languageManager()->getLanguages();

    $form['description'] = [
      '#markup' => $this->t('Enable 24-hour time format for the following languages used in Webform date/time fields.'),
    ];

    foreach ($languages as $langcode => $language) {
      $form[$langcode] = [
        '#type' => 'checkbox',
        '#title' => $language->getName(),
        '#default_value' => $config->get($langcode) ?? FALSE,
      ];
    }

    $format_options = [
      'HH:mm|H:i' => $this->t('19:30 (default)'),
      'HH[ h ]mm|H \h i' => $this->t('19 h 30'),
    ];

    $default = implode('|', $config->get('display_time_format') ?? ['HH:mm', 'H:i']);

    $form['display_time_format'] = [
      '#type' => 'radios',
      '#title' => $this->t('24h Time Display Format'),
      '#description' => $this->t('Choose how 24h time values should be displayed in the time picker.'),
      '#options' => $format_options,
      '#default_value' => $default,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $languages = $this->languageManager()->getLanguages();
    $config = $this->config('webform_datetime_24h.settings');

    foreach ($languages as $langcode => $language) {
      $config->set($langcode, $form_state->getValue($langcode));
    }

    [$js, $php] = explode('|', $form_state->getValue('display_time_format'));
    $config->set('display_time_format', [
      'js' => $js,
      'php' => $php,
    ]);

    $config->save();
    $this->messenger()->addStatus($this->t('Webform Datetime 24h settings have been saved.'));
  }

  /**
   * Helper to access the language manager.
   */
  protected function languageManager(): LanguageManagerInterface {
    return \Drupal::languageManager();
  }

}

